@@ -1,12 +1,11 @@
 # $Id: ptte.data.R,v 1.2 2005/09/26 02:29:00 andrewr Exp $
 
 "ptte.data" <-
-function(x, alpha=0.05, Epsilon=0.25, absolute=FALSE) {
+function(x, alpha=0.05, Epsilon=0.25) {
     mean <- mean(x, na.rm=TRUE); std <- sd(x, na.rm=TRUE)
     n <- length(x) - sum(is.na(x))
     df1 <- 1; df2 <- n-1; cutoff <- c(0)
     if(length(Epsilon)>1) stop("Asymmetric intervals are not implemented")
-    if (absolute) Epsilon <- Epsilon / std
     ncp <- Epsilon^2 * n; 
     findquant <- function(alpha, q, df1, df2, ncp)
         alpha - pf(q, df1, df2, ncp)
